@@ -77,6 +77,23 @@ MainWindow::MainWindow()
     , _menuBarInitialVisibility(true)
     , _menuBarInitialVisibilityApplied(false)
 {
+    if (!KonsoleSettings::saveGeometryOnExit()) {
+        // If we are not using the global Konsole save geometry on exit,
+        // remove all Height and Width from [MainWindow] from konsolerc
+        // Each screen resolution will have entries (Width 1280=619)
+        KSharedConfigPtr konsoleConfig = KSharedConfig::openConfig("konsolerc");
+        KConfigGroup group = konsoleConfig->group("MainWindow");
+        QMap<QString, QString> configEntries = group.entryMap();
+        QMapIterator<QString, QString> i(configEntries);
+        while (i.hasNext()) {
+            i.next();
+            if (i.key().startsWith(QLatin1String("Width")) 
+                    || i.key().startsWith(QLatin1String("Height"))) {
+                group.deleteEntry(i.key());
+            }
+        }
+    }
+
     if (useTransparency()) {
         // It is useful to have translucent terminal area
         setAttribute(Qt::WA_TranslucentBackground, true);
@@ -97,8 +114,6 @@ MainWindow::MainWindow()
     connect(_viewManager, SIGNAL(viewPropertiesChanged(QList<ViewProperties*>)),
             bookmarkHandler(), SLOT(setViews(QList<ViewProperties*>)));
 
-    connect(_viewManager, SIGNAL(setSaveGeometryOnExitRequest(bool)), this,
-            SLOT(setSaveGeometryOnExit(bool)));
     connect(_viewManager, SIGNAL(updateWindowIcon()), this,
             SLOT(updateWindowIcon()));
     connect(_viewManager, SIGNAL(newViewRequest(Profile::Ptr)),
@@ -166,12 +181,6 @@ void MainWindow::restoreMenuAccelerators()
     }
 }
 
-void MainWindow::setSaveGeometryOnExit(bool save)
-{
-    // enable save and restore of window size
-    setAutoSaveSettings("MainWindow", save);
-}
-
 void MainWindow::correctStandardShortcuts()
 {
     // replace F1 shortcut for help contents
@@ -266,7 +275,11 @@ void MainWindow::updateWindowCaption()
         caption = userTitle;
     }
 
-    setCaption(caption);
+    if (KonsoleSettings::showAppNameOnTitleBar()) {
+        setCaption(caption);
+    } else {
+        setPlainCaption(caption);
+    }
 }
 
 void MainWindow::updateWindowIcon()
@@ -325,7 +338,7 @@ void MainWindow::setupActions()
 
     // Full Screen
     menuAction = KStandardAction::fullScreen(this, SLOT(viewFullScreen(bool)), this, collection);
-    menuAction->setShortcut(QKeySequence());
+    menuAction->setShortcut(QKeySequence(Qt::Key_F11));
 
     KStandardAction::configureNotifications(this, SLOT(configureNotifications()), collection);
     KStandardAction::keyBindings(this, SLOT(showShortcutsDialog()), collection);
@@ -685,11 +698,17 @@ void MainWindow::applyKonsoleSettings()
 
     setNavigationVisibility(KonsoleSettings::tabBarVisibility());
     setNavigationPosition(KonsoleSettings::tabBarPosition());
-    setNavigationStyleSheet(KonsoleSettings::tabBarStyleSheet());
     setNavigationBehavior(KonsoleSettings::newTabBehavior());
     setShowQuickButtons(KonsoleSettings::showQuickButtons());
 
-    // setAutoSaveSettings("MainWindow", KonsoleSettings::saveGeometryOnExit());
+    if (KonsoleSettings::tabBarUseUserStyleSheet()) {
+        setNavigationStyleSheetFromFile(KonsoleSettings::tabBarUserStyleSheetFile());
+    } else {
+        // Apply default values
+        setNavigationStyleSheet(KonsoleSettings::tabBarStyleSheet());
+    }
+
+    setAutoSaveSettings("MainWindow", KonsoleSettings::saveGeometryOnExit());
 
     updateWindowCaption();
 }
@@ -714,6 +733,28 @@ void MainWindow::setNavigationBehavior(int behavior)
     _viewManager->setNavigationBehavior(behavior);
 }
 
+void MainWindow::setNavigationStyleSheetFromFile(const KUrl& styleSheetFile)
+{
+    // Let's only deal w/ local files for now
+    if (!styleSheetFile.isLocalFile()) {
+        setNavigationStyleSheet(KonsoleSettings::tabBarStyleSheet());
+    }
+
+    QFile file(styleSheetFile.toLocalFile());
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        setNavigationStyleSheet(KonsoleSettings::tabBarStyleSheet());
+    }
+
+    QString styleSheetText;
+    QTextStream in(&file);
+    while (!in.atEnd()) {
+        styleSheetText.append(in.readLine());
+    }
+
+    // Replace current style sheet w/ loaded file
+    setNavigationStyleSheet(styleSheetText);
+}
+
 void MainWindow::setShowQuickButtons(bool show)
 {
     _viewManager->setShowQuickButtons(show);
